@@ -19,7 +19,7 @@ class PassthroughCommand:
         output = PassthroughCommand._passthrough(config)
         output_file = config.output_file
         output_dir = os.path.dirname(output_file)
-        if not os.path.isdir(output_dir):
+        if len(output_dir) > 0 and not os.path.isdir(output_dir):
             print(  # noqa: T201
                 f"error: output directory does not exist: {output_file}"
             )
