@@ -1,14 +1,10 @@
 from typing import Optional
 
+from reqif.helpers.debug import auto_described
 from reqif.models.reqif_req_if_content import ReqIFReqIFContent
 
 
+@auto_described
 class ReqIFCoreContent:
     def __init__(self, req_if_content: Optional[ReqIFReqIFContent]):
         self.req_if_content: Optional[ReqIFReqIFContent] = req_if_content
-
-    def __str__(self) -> str:
-        return "ReqIFCoreContent()"
-
-    def __repr__(self) -> str:
-        return self.__str__()
